==> nextcloud-26.0.9.tgz: nextcloud/apps/serverinfo/l10n/es_EC.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Información de la CPU no disponible",
    "Load average: {cpu} (last minute)" : "Promedio de carga: {cpu} (último minuto)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes}/Uso actual: {memUsageBytes}",
    "RAM info not available" : "Información de RAM no disponible",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Uso actual: {swapUsageBytes}",
    "SWAP info not available" : "Información de SWAP no disponible",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Monitoreo",
    "Monitoring app with useful server information" : "Aplicación de monitoreo con información útil del servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Proporciona información útil del servidor, como carga de CPU, uso de RAM, uso de disco, número de usuarios, etc.",
    "Operating System:" : "Sistema operativo:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Procesador desconocido",
    "Memory:" : "Memoria:",
    "Server time:" : "Hora del servidor:",
    "Uptime:" : "Tiempo de actividad:",
    "Temperature" : "Temperatura",
    "Load" : "Carga",
    "Memory" : "Memoria",
    "Disk" : "Disco",
    "Mount:" : "Montaje:",
    "Filesystem:" : "Sistema de archivos:",
    "Size:" : "Tamaño:",
    "Available:" : "Disponible:",
    "Used:" : "Usado:",
    "Files:" : "Archivos:",
    "Storages:" : "Almacenamientos:",
    "Free Space:" : "Espacio libre:",
    "Network" : "Red",
    "Hostname:" : "Nombre del host:",
    "DNS:" : "DNS:",
    "Gateway:" : "Gateway:",
    "Status:" : "Estado:",
    "Speed:" : "Velocidad:",
    "Duplex:" : "Dúplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Usuarios activos",
    "Total users:" : "Total de usuarios:",
    "24 hours:" : "24 horas:",
    "1 hour:" : "1 hora:",
    "5 mins:" : "5 minutos:",
    "Shares" : "Elementos compartido",
    "Users:" : "Usuarios:",
    "Groups:" : "Grupos:",
    "Links:" : "Enlaces:",
    "Emails:" : "Correos electrónicos:",
    "Federated sent:" : "Enviados federados:",
    "Federated received:" : "Recibidos federados:",
    "Talk conversations:" : "Conversaciones de Talk:",
    "PHP" : "PHP",
    "Version:" : "Versión:",
    "Memory limit:" : "Límite de memoria:",
    "Max execution time:" : "Tiempo máximo de ejecución:",
    "Upload max size:" : "Tamaño máximo de carga:",
    "OPcache Revalidate Frequency:" : "Frecuencia de revalidación de OPcache:",
    "Extensions:" : "Extensiones:",
    "Unable to list extensions" : "No se pueden enumerar las extensiones",
    "Show phpinfo" : "Mostrar phpinfo",
    "Database" : "Base de datos",
    "Type:" : "Tipo:",
    "External monitoring tool" : "Herramienta de monitoreo externa",
    "Copy" : "Copiar",
    "To use an access token, please generate one then set it using the following command:" : "Para usar un token de acceso, por favor genera uno y luego configúralo usando el siguiente comando:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Luego pasa el token con la cabecera \"NC-Token\" al consultar la URL anterior.",
    "You will get a notification once one of your disks is nearly full." : "Recibirás una notificación cuando uno de tus discos esté casi lleno.",
    "You can connect an external monitoring tool by using this end point:" : "Puedes conectar una herramienta de monitoreo externa usando este punto final:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Agregando \"?format=json\" al final de la URL te dará el resultado en formato JSON."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-27.1.3.tgz: nextcloud/apps/serverinfo/l10n/es_EC.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Información de la CPU no disponible",
    "Load average: {cpu} (last minute)" : "Promedio de carga: {cpu} (último minuto)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes}/Uso actual: {memUsageBytes}",
    "RAM info not available" : "Información de RAM no disponible",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Uso actual: {swapUsageBytes}",
    "SWAP info not available" : "Información de SWAP no disponible",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Monitoreo",
    "Monitoring app with useful server information" : "Aplicación de monitoreo con información útil del servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Proporciona información útil del servidor, como carga de CPU, uso de RAM, uso de disco, número de usuarios, etc.",
    "Operating System:" : "Sistema operativo:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Procesador desconocido",
    "Memory:" : "Memoria:",
    "Server time:" : "Hora del servidor:",
    "Uptime:" : "Tiempo de actividad:",
    "Temperature" : "Temperatura",
    "Load" : "Carga",
    "Memory" : "Memoria",
    "Disk" : "Disco",
    "Mount:" : "Montaje:",
    "Filesystem:" : "Sistema de archivos:",
    "Size:" : "Tamaño:",
    "Available:" : "Disponible:",
    "Used:" : "Usado:",
    "Files:" : "Archivos:",
    "Storages:" : "Almacenamientos:",
    "Free Space:" : "Espacio libre:",
    "Network" : "Red",
    "Hostname:" : "Nombre del host:",
    "DNS:" : "DNS:",
    "Gateway:" : "Gateway:",
    "Status:" : "Estado:",
    "Speed:" : "Velocidad:",
    "Duplex:" : "Dúplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Usuarios activos",
    "Total users:" : "Total de usuarios:",
    "24 hours:" : "24 horas:",
    "1 hour:" : "1 hora:",
    "5 mins:" : "5 minutos:",
    "Shares" : "Elementos compartido",
    "Users:" : "Usuarios:",
    "Groups:" : "Grupos:",
    "Links:" : "Enlaces:",
    "Emails:" : "Correos electrónicos:",
    "Federated sent:" : "Enviados federados:",
    "Federated received:" : "Recibidos federados:",
    "Talk conversations:" : "Conversaciones de Talk:",
    "PHP" : "PHP",
    "Version:" : "Versión:",
    "Memory limit:" : "Límite de memoria:",
    "Max execution time:" : "Tiempo máximo de ejecución:",
    "Upload max size:" : "Tamaño máximo de carga:",
    "OPcache Revalidate Frequency:" : "Frecuencia de revalidación de OPcache:",
    "Extensions:" : "Extensiones:",
    "Unable to list extensions" : "No se pueden enumerar las extensiones",
    "Show phpinfo" : "Mostrar phpinfo",
    "Database" : "Base de datos",
    "Type:" : "Tipo:",
    "External monitoring tool" : "Herramienta de monitoreo externa",
    "You can connect an external monitoring tool by using this end point:" : "Puedes conectar una herramienta de monitoreo externa usando este punto final:",
    "Copy" : "Copiar",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Agregando \"?format=json\" al final de la URL te dará el resultado en formato JSON.",
    "To use an access token, please generate one then set it using the following command:" : "Para usar un token de acceso, por favor genera uno y luego configúralo usando el siguiente comando:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Luego pasa el token con la cabecera \"NC-Token\" al consultar la URL anterior.",
    "You will get a notification once one of your disks is nearly full." : "Recibirás una notificación cuando uno de tus discos esté casi lleno."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
